@@ -9,7 +9,9 @@ __all__ = [
     'HEADERS_REQUEST',
     'SITE_RETURNING_URL',
     'FILE_PATH_BAD',
+    'CTA',
 ]
+CTA = 'cloudtipsadp'
 BASE_URL = 'https://identity.cloudtips.ru'
 BASE_URL_SANDBOX = 'https://identity-sandbox.cloudtips.ru'
 BASE_URL_API = 'https://api.cloudtips.ru/api'
