@@ -1,7 +1,5 @@
 from typing import Type
 
-from loguru import logger
-
 from cloudtipsadp.clients import (Connect, ProductClient, SandboxClient)
 from cloudtipsadp.accumulations import Accumulation, Accumulations
 from cloudtipsadp.cards import (Card, Cards, FlowBase)
@@ -36,41 +34,34 @@ class Cloudtipsadp:
         self.receivers_pages = _receiver_pages
         self.receivers_photo = _receiver_photo
 
-    @logger.catch
     def connect(self, sandbox=False):
         """Подключение."""
         if sandbox:
             self.__link = self.__connect(self.__sandbox_client())
         self.__link = self.__connect()
 
-    @logger.catch
     def get_token(self):
         return self.__connect.get_token()
 
-    @logger.catch
     def refresh_token(self):
         return self.__link.refresh_token()
 
 
-@logger.catch
 def _accum_get(accumulation: Accumulation):
     """Получить общую сумму донатов, по сотруднику."""
     return accumulation.get()
 
 
-@logger.catch
 def _card_auth(card: Card):
     """Отправить криптограмму."""
     return card.auth()
 
 
-@logger.catch
 def _card_get(card: Card):
     """Список карт получателя."""
     return card.get()
 
 
-@logger.catch
 def _card_flow(flow: FlowBase):
     if isinstance(flow, FlowBase):
         return flow.auth()
@@ -78,13 +69,11 @@ def _card_flow(flow: FlowBase):
         print('Error, type mismatch.')
 
 
-@logger.catch
 def _payout_get(payout: Payout):
     """ Получение всех транзакций выплат получателям менеджера."""
     return payout.get()
 
 
-@logger.catch
 def _place_confirm(place: Place):
     """
     Передать код из смс.
@@ -93,13 +82,11 @@ def _place_confirm(place: Place):
     return place.confirm()
 
 
-@logger.catch
 def _place_get(place: Place):
     """Информация по всем заведениям ТСП."""
     return place.get()
 
 
-@logger.catch
 def _place_send(place: Place):
     """
     Привязка получателя к заведению.
@@ -108,19 +95,16 @@ def _place_send(place: Place):
     return place.send()
 
 
-@logger.catch
 def _receiver_create(receiver: Receiver):
     """Создать получателя донатов."""
     return receiver.create()
 
 
-@logger.catch
 def _receiver_pages(receiver: Receiver):
     """Все получатели донатов."""
     return receiver.pages()
 
 
-@logger.catch
 def _receiver_photo(receiver: Receiver):
     """Загрузить фотографию получателя."""
     return receiver.photo()
